import ast
import sys

sys.path.append('..')

import test_docstrings

T = test_docstrings.TestDocstrings


def test_regular_function():
    "Regular function wo docstring should not fail"
    assert list(T(ast.parse('def func(): pass')).run()) == []


def test_test_with_docstring():
    "Test method with docstring should not fail"
    assert list(T(ast.parse('def test_func(): "docstring"')).run()) == []


def test_test_wo_docstring():
    "Test method without docstring should fail with `42cc1` code"
    assert list(T(ast.parse('def test_func(): pass')).run()) == [
        (1, 0, '42cc1: Test has no docstring', '42cc1')]



"""Function should not be too long"""

import ast


class TestLenFunction(object):
    name = 'test_lenfunction'
    version = '0.0.1'
    threshold = 40  # should have less than 40 statements in a function

    def __init__(self, tree, filename='(none)', builtins=None):
        self.tree = tree
        self.filename = filename

    def run(self):
        """Check that functions are less than threshold"""
        for stmt in ast.walk(self.tree):
            if isinstance(stmt, ast.FunctionDef) \
               and len(stmt.body) > self.threshold:
                yield (stmt.lineno, stmt.col_offset,
                       '42cc2: Function should be shorter than '
                       '%d statements' % self.threshold,
                       '42cc2',
                       )
